.. image:: https://travis-ci.org/timcera/wdmtoolbox.svg?branch=master
    :target: https://travis-ci.org/timcera/wdmtoolbox
    :height: 20

.. image:: https://coveralls.io/repos/timcera/wdmtoolbox/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/wdmtoolbox?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/wdmtoolbox.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/wdmtoolbox

.. image:: http://img.shields.io/badge/license-BSD-lightgrey.svg
    :alt: BSD-3 clause license
    :target: https://pypi.python.org/pypi/wdmtoolbox/

.. image:: http://img.shields.io/pypi/dd/wdmtoolbox.svg
    :alt: wdmtoolbox downloads
    :target: https://pypi.python.org/pypi/wdmtoolbox/
